=======
History
=======

0.1.6 (2021-01-25)
------------------

- Add CSV format switch support
- Various dependency upgrades


0.1.5 (2020-05-22)
------------------

- Include missing files in sdist
- Update pip to 20.1.1
- Update bumpversion to 0.6.0
- Update flake8 to 3.8.1
- Update pytest to 5.4.2
- Update requests-mock to 1.8.0


0.1.4 (2020-04-28)
------------------

- add support for RPC endpoints
- add support for websocket endpoints
- add examples for rpc and websocket calls
- update coverage to 5.1
- update sphinx to 3.0.3


0.1.3 (2020-03-16)
------------------

- update coverage from 4.5.4 to 5.0.3
- update flake8 from 3.7.8 to 3.7.9
- update pip from 19.2.3 to 20.0.2
- update pytest from 4.6.5 to 5.4.1
- update pytest-runner from 5.1 to 5.2
- update sphinx from 1.8.5 to 2.4.4
- update twine from 1.14.0 to 3.1.1
- update watchdog from 0.9.0 to 0.10.2
- update wheel from 0.33.6 to 0.34.2


0.1.1 + 0.1.2 (2020-03-15)
--------------------------

Add minor documentation, markup, and package publishing fixes


0.1.0 (2020-03-15)
------------------

First release on PyPI


0.0.1 (2020-03-13)
------------------

First implementation for the
`Amberdata developer challenge <https://medium.com/amberdata/developer-challenge-scale-defi-digital-assets-d71015200325>`_
